@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02111-1307, USA.
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
@@ -1491,7 +1491,7 @@ gnome_canvas_pango_draw_cairo (GPrintable *gprintable, cairo_t *cr)
 	double ax, ay;
 	g_return_if_fail (text);
 	adjust_for_anchors (text, &ax, &ay);
-	cairo_move_to (cr, ax, ay);
+	cairo_translate (cr, ax, ay);
 	pango_cairo_show_layout (cr, text->_priv->layout);
 }
 
