@@ -118,6 +118,12 @@ bool Fragment::OnChanged (bool save)
 		m_ascent = pango_layout_iter_get_baseline (iter) / PANGO_SCALE;
 		pango_layout_iter_free (iter);
 	}
+	if (m_buf.length () < m_EndAtom) { // needed if the symbol of part of it has been destroyed
+		m_Atom->SetZ (0);
+		m_EndAtom = m_buf.length ();
+		if (m_BeginAtom > m_EndAtom)
+			m_BeginAtom = m_EndAtom;
+	}
 	/*main atom management*/
 	FragmentResidue *residue = dynamic_cast <FragmentResidue*> (m_Atom);
 	Residue *r = NULL;
@@ -1036,7 +1042,7 @@ Object* Fragment::GetAtomAt (double x, double y, double z)
 		cur--;
 		c = m_buf[cur];
 	}
-	if (index - cur > Residue::MaxSymbolLength)
+	if (index - cur > static_cast <int> (Residue::MaxSymbolLength))
 		cur = index - Residue::MaxSymbolLength;
 	if (cur < 0)
 		cur = 0;
