@@ -4,7 +4,7 @@
  * GChemPaint library
  * molecule.cc 
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,11 +29,19 @@
 #include "application.h"
 #include "tool.h"
 #include "stringdlg.h"
+#include <gcu/chain.h>
 #include <glib/gi18n-lib.h>
 #include <unistd.h>
 #include <openbabel/obconversion.h>
 #include <clocale>
 #include <cmath>
+#include <cstring>
+#include <map>
+#include <set>
+
+using namespace gcu;
+using namespace OpenBabel;
+using namespace std;
 
 namespace gcp {
 
@@ -73,18 +81,15 @@ static void do_open_in_calc (Molecule* pMol)
 	pMol->OpenCalc ();
 }
 
-Molecule::Molecule (TypeId Type): Object (Type)
+Molecule::Molecule (TypeId Type): gcu::Molecule (Type)
 {
 	m_Alignment = NULL;
 	m_Changed = true;
 	m_IsResidue = false;
 }
 
-Molecule::Molecule (Atom* pAtom): Object (MoleculeType)
+Molecule::Molecule (Atom* pAtom): gcu::Molecule  (pAtom)
 {
-	AddAtom (pAtom);
-	Chain* pChain = new Chain (this, pAtom); //will find the cycles
-	delete pChain;
 	m_Alignment = NULL;
 	m_Changed = true;
 	m_IsResidue = false;
@@ -92,40 +97,62 @@ Molecule::Molecule (Atom* pAtom): Object (MoleculeType)
 
 Molecule::~Molecule ()
 {
-	std::list<Bond*>::iterator n, end = m_Bonds.end ();
-	for (n = m_Bonds.begin (); n != end; n++)
-		(*n)->RemoveAllCycles ();
-	while (!m_Cycles.empty ()) {
-		delete m_Cycles.front ();
-		m_Cycles.pop_front ();
+}
+
+void Molecule::Add (GtkWidget* w) const
+{
+	std::list<gcu::Atom*>::const_iterator i, iend = m_Atoms.end ();
+	for (i = m_Atoms.begin (); i != iend; i++)
+		(*i)->Add (w);
+	std::list<Fragment*>::const_iterator j, jend = m_Fragments.end ();
+	for (j = m_Fragments.begin (); j != jend; j++)
+		(*j)->Add (w);
+	std::list<gcu::Bond*>::const_iterator k, kend = m_Bonds.end ();
+	for (k = m_Bonds.begin (); k != kend; k++)
+		(*k)->Add (w);
+}
+
+void Molecule::AddChild (Object* object)
+{
+	switch (object->GetType ()) {
+	case gcu::AtomType:
+			if (object->GetParent () && object->GetParent ()->GetType () == FragmentType)
+				object = object->GetParent ();
+			else {
+				gcu::Molecule::AddChild (object);
+				break;
+			}
+	case FragmentType: {
+		Fragment *fragment = reinterpret_cast<Fragment *> (object);
+		m_Fragments.remove (fragment);
+		AddFragment (fragment);
+		break;
 	}
-	while (!m_Chains.empty ()) {
-		delete m_Chains.front ();
-		m_Chains.pop_front ();
+	default:
+		gcu::Molecule::AddChild (object);
+		break;
 	}
 }
 
-void Molecule::AddAtom (Atom* pAtom)
+void Molecule::AddAtom (gcu::Atom* pAtom)
 {
-	m_Atoms.remove (pAtom); // avoid duplicates
-	m_Atoms.push_back (pAtom);
-	AddChild (pAtom);
+	gcu::Molecule::AddAtom (pAtom);
 	if (!pAtom->GetZ ())
 		m_IsResidue = true;
 }
 
 void Molecule::AddFragment (Fragment* pFragment)
 {
+	m_Fragments.remove (pFragment); // just in case
 	m_Fragments.push_back (pFragment);
-	AddChild (pFragment);
+	Object::AddChild (pFragment);
 } 
 
-void Molecule::AddBond (Bond* pBond)
+void Molecule::AddBond (gcu::Bond* pBond)
 {
 	if (pBond->GetAtom (0) && pBond->GetAtom (1))
-		CheckCrossings (pBond);
-	m_Bonds.push_back (pBond);
-	AddChild (pBond);
+		CheckCrossings (reinterpret_cast <Bond *> (pBond));
+	gcu::Molecule::AddBond (pBond);
 	EmitSignal (OnChangedSignal);
 }
 
@@ -134,25 +161,16 @@ void Molecule::Remove (Object* pObject)
 	if (pObject == m_Alignment)
 		m_Alignment = NULL;
 	switch (pObject->GetType ()) {
-	case AtomType:
-		m_Atoms.remove ((Atom*) pObject);
-		break;
-	case gcu::BondType:
-		m_Bonds.remove ((Bond*) pObject);
-		break;
 	case FragmentType:
 		m_Fragments.remove ((Fragment*) pObject);
 		break;
+	default:
+		gcu::Molecule::Remove (pObject);
+		break;
 	}
 	pObject->SetParent (GetParent ());
 }
 
-void Molecule::UpdateCycles (Bond* pBond)	//FIXME: function not totally implemented
-{
-	Chain* pChain = new Chain (this, pBond); //will find the cycles
-	delete pChain;
-}
-
 typedef struct {
 	Atom *pAtom;
 	int sb; // number of shared bonds
@@ -167,7 +185,7 @@ bool Molecule::Merge (Molecule* pMolecule, bool RemoveDuplicates)
 	Chain* pChain;
 	Cycle* pCycle;
 	if (RemoveDuplicates) {
-		std::list<Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
+		std::list<gcu::Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
 		double x, y, x0, y0, x1, y1;
 		MergedAtom *ma;
 		Bond *b0, *b1;
@@ -207,7 +225,7 @@ bool Molecule::Merge (Molecule* pMolecule, bool RemoveDuplicates)
 						}
 					}
 				}
-				AtomMap[*i] = ma;
+				AtomMap[reinterpret_cast <Atom *> (*i)] =  ma;
 			}
 		}
 		// Now check if merging is possible for each shared atom.
@@ -306,7 +324,7 @@ bool Molecule::Merge (Molecule* pMolecule, bool RemoveDuplicates)
 		if (!DoMerge) return false;
 	}
 	while (!pMolecule->m_Atoms.empty ()) {
-		pAtom = pMolecule->m_Atoms.front ();
+		pAtom =  reinterpret_cast <Atom *> (pMolecule->m_Atoms.front ());
 		AddAtom (pAtom);
 		pMolecule->m_Atoms.pop_front ();
 	}
@@ -316,7 +334,7 @@ bool Molecule::Merge (Molecule* pMolecule, bool RemoveDuplicates)
 		pMolecule->m_Fragments.pop_front ();
 	}
 	while (!pMolecule->m_Bonds.empty ()) {
-		pBond = pMolecule->m_Bonds.front ();
+		pBond =  reinterpret_cast <Bond *> (pMolecule->m_Bonds.front ());
 		AddBond (pBond);
 		pMolecule->m_Bonds.pop_front ();
 	}
@@ -381,18 +399,18 @@ bool Molecule::Load (xmlNodePtr node)
 		AddAtom ((Atom*) pObject);
 		child = GetNextNodeByName (child->next, "pseudo-atom");
 	}
-	
+
 	child = GetNodeByName (node, "fragment");
 	while (child) {
 		pObject = new Fragment ();
-		AddChild (pObject);
+		if (pDoc)
+			AddChild (pObject);
 		if (!pObject->Load (child))  {
 			delete pObject;
 			return false;
 		}
 		if (pDoc)
 			pDoc->AddFragment ((Fragment*) pObject);
-		AddFragment ((Fragment*) pObject);
 		child = GetNextNodeByName (child->next, "fragment");
 	}
 
@@ -411,11 +429,15 @@ bool Molecule::Load (xmlNodePtr node)
 		CheckCrossings ((Bond*) pObject);
 	}
 	if (!m_Atoms.empty ()) {
-		Atom* pAtom = m_Atoms.front ();
-		std::list<Atom*>::iterator i = m_Atoms.begin ();
+		Atom* pAtom =  reinterpret_cast <Atom *> (m_Atoms.front ());
+		list<gcu::Atom*>::iterator i = m_Atoms.begin ();
 		i++;
 		for (; i != m_Atoms.end (); i++)
 			(*i)->SetParent (NULL);
+		// erase cycles
+		list<gcu::Bond*>::iterator j, jend = m_Bonds.end ();
+		for (j = m_Bonds.begin (); j != jend; j++)
+			(*j)->RemoveAllCycles ();
 		Chain* pChain = new Chain (this, pAtom); //will find the cycles
 		delete pChain;
 	}
@@ -430,27 +452,6 @@ bool Molecule::Load (xmlNodePtr node)
 	return true;
 }
 
-void Molecule::UpdateCycles ()
-{
-	Lock (true);
-	std::list<Bond*>::iterator n, end = m_Bonds.end ();
-	for (n = m_Bonds.begin (); n != end; n++)
-		(*n)->RemoveAllCycles ();
-	while (!m_Cycles.empty()) {
-		delete m_Cycles.front ();
-		m_Cycles.pop_front ();
-	}
-	if (!m_Atoms.empty()) {
-		std::list<Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
-		i++;
-		for (; i != end; i++)
-			(*i)->SetParent(NULL);
-		Chain* pChain = new Chain (this, *(m_Atoms.begin ())); //will find the cycles
-		delete pChain;
-	}
-	Lock (false);
-}
-
 void Molecule::Clear ()
 {
 	m_Bonds.clear ();
@@ -458,29 +459,19 @@ void Molecule::Clear ()
 	m_Fragments.clear ();
 }
 
-void Molecule::SetSelected (GtkWidget* w, int state)
-{
-	map<string, Object*>::iterator i;
-	Object *child = GetFirstChild (i);
-	while (child) {
-		child->SetSelected (w, state);
-		child = GetNextChild (i);
-	}
-}
-
 void Molecule::Transform2D (Matrix2D& m, double x, double y)
 {
 	Object::Transform2D (m, x, y);
-	std::list<Atom*>::iterator i = m_Atoms.begin ();
+	std::list<gcu::Atom*>::iterator i = m_Atoms.begin ();
 	for (; i != m_Atoms.end (); i++)
-	if (((*i)->GetZ () != 6) && (*i)->GetAttachedHydrogens () &&
-		(*i)->GetBondsNumber ()) (*i)->Update ();
+	if (((*i)->GetZ () != 6) &&  reinterpret_cast <Atom *> (*i)->GetAttachedHydrogens () &&
+		(*i)->GetBondsNumber ())  reinterpret_cast <Atom *> (*i)->Update ();
 }
 
 Object* Molecule::GetAtomAt (double x, double y, double z)
 {
 	// Make use of Bond::GetAtomAt
-	std::list<Bond*>::iterator n, end = m_Bonds.end ();
+	std::list<gcu::Bond*>::iterator n, end = m_Bonds.end ();
 	Object* pObj = NULL;
 	for (n = m_Bonds.begin(); n != end; n++)
 		if ((pObj = (*n)->GetAtomAt (x, y)))
@@ -493,9 +484,9 @@ double Molecule::GetYAlign ()
 	if (m_Alignment)
 		return m_Alignment->GetYAlign ();
 	double y, maxy = - DBL_MAX, miny = DBL_MAX;
-	std::list<Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
+	std::list<gcu::Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
 	for (; i != end; i++) {
-		y = (*i)->GetYAlign ();
+		y =  reinterpret_cast <Atom *> (*i)->GetYAlign ();
 		if (y < miny)
 			miny = y;
 		if (y > maxy)
@@ -516,12 +507,12 @@ bool Molecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object, dou
 {
 	if (m_IsResidue)
 		return false;
-	bool result = false;
 	GtkActionGroup *group = gtk_action_group_new ("molecule");
 	GtkAction *action;
 	action = gtk_action_new ("Molecule", _("Molecule"), NULL, NULL);
 	gtk_action_group_add_action (group, action);
 	g_object_unref (action);
+	bool result = false;
 	if (!m_Fragments.size ()) {
 		if (((Document*) GetDocument ())->GetApplication ()->HaveGhemical ()) {
 			action = gtk_action_new ("ghemical", _("Export molecule to Ghemical"), NULL, NULL);
@@ -568,8 +559,7 @@ bool Molecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object, dou
 		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='select-align'/></menu></popup></ui>", -1, NULL);
 		result = true;
 	}
-	if (result)
-		gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	gtk_ui_manager_insert_action_group (UIManager, group, 0);
 	g_object_unref (group);
 	return result | Object::BuildContextualMenu (UIManager, object, x, y);
 }
@@ -606,7 +596,7 @@ void Molecule::SelectAlignmentItem (Object *child)
 	EmitSignal (OnChangedSignal);
 }
 
-xmlNodePtr Molecule::Save (xmlDocPtr xml)
+xmlNodePtr Molecule::Save (xmlDocPtr xml) const
 {
 	xmlNodePtr node = Object::Save (xml);
 	if (!node)
@@ -621,8 +611,8 @@ void Molecule::BuildOBMol (OBMol &Mol)
 	double xav = 0., yav = 0., zf;
 	unsigned n = m_Atoms.size ();
 	map<string, unsigned> AtomTable;
-	list<Atom*>::iterator ia, enda = m_Atoms.end ();
-	list<Bond*> BondList;
+	list<gcu::Atom*>::iterator ia, enda = m_Atoms.end ();
+	list<gcu::Bond*> BondList;
 	double x, y, z;
 	for (ia = m_Atoms.begin (); ia != enda; ia++) {
 		(*ia)->GetCoords(&x, &y, &z);
@@ -639,7 +629,7 @@ void Molecule::BuildOBMol (OBMol &Mol)
 	Mol.BeginModify ();
 	Mol.ReserveAtoms (n);
 	for (ia = m_Atoms.begin (); ia != enda; ia++) {
-		pgAtom = *ia;
+		pgAtom =  reinterpret_cast <Atom *> (*ia);
 		AtomTable [pgAtom->GetId ()] = index;
 		obAtom.SetIdx (index++);
 		obAtom.SetAtomicNum (pgAtom->GetZ());
@@ -660,11 +650,11 @@ void Molecule::BuildOBMol (OBMol &Mol)
 			}
 			pBond = (Bond*) pgAtom->GetNextBond (i);
 		}
-		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, z / 100);
+		obAtom.SetVector ((xav - x) / 100, (yav - y) / 100, z / 100);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
-	list<Bond*>::iterator j, endb = m_Bonds.end ();
+	list<gcu::Bond*>::iterator j, endb = m_Bonds.end ();
 	int start, end, order;
 	for (j = m_Bonds.begin (); j != endb; j++)
 	{
@@ -681,8 +671,8 @@ void Molecule::BuildOBMol2D (OBMol &Mol)
 	double xav = 0., yav = 0.;
 	unsigned n = m_Atoms.size ();
 	map<string, unsigned> AtomTable;
-	list<Atom*>::iterator ia, enda = m_Atoms.end ();
-	list<Bond*> BondList;
+	list<gcu::Atom*>::iterator ia, enda = m_Atoms.end ();
+	list<gcu::Bond*> BondList;
 	double x, y, z;
 	for (ia = m_Atoms.begin (); ia != enda; ia++) {
 		(*ia)->GetCoords (&x, &y, &z);
@@ -699,33 +689,31 @@ void Molecule::BuildOBMol2D (OBMol &Mol)
 	Mol.ReserveAtoms (n);
 	Mol.SetDimension (2);
 	for (ia = m_Atoms.begin (); ia != enda; ia++) {
-		pgAtom = *ia;
+		pgAtom =  reinterpret_cast <Atom *> (*ia);
 		AtomTable [pgAtom->GetId ()] = index;
 		obAtom.SetIdx (index++);
 		obAtom.SetAtomicNum (pgAtom->GetZ());
 		pgAtom->GetCoords (&x, &y, &z);
 		// Scans the atom bonds and change z to try conservation of stereochemistry
-		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, 0.);
+		obAtom.SetVector ((x - xav)/ 100, (yav - y) / 100, 0.);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
-	list<Bond*>::iterator j, endb = m_Bonds.end ();
+	list<gcu::Bond*>::iterator j, endb = m_Bonds.end ();
 	int start, end, order, flag;
-	for (j = m_Bonds.begin (); j != endb; j++)
-	{
+	for (j = m_Bonds.begin (); j != endb; j++) {
 		order = (*j)->GetOrder ();
 		start = AtomTable[(*j)->GetAtom (0)->GetId ()];
 		end = AtomTable[(*j)->GetAtom (1)->GetId ()];
-		switch((*j)->GetType ())
-		{
-			case UpBondType:
-				flag = OB_WEDGE_BOND;
-				break;
-			case DownBondType:
-				flag = OB_HASH_BOND;
-				break;
-			default:
-				flag = 0;
+		switch (reinterpret_cast <Bond *> (*j)->GetType ()) {
+		case UpBondType:
+			flag = OB_WEDGE_BOND;
+			break;
+		case DownBondType:
+			flag = OB_HASH_BOND;
+			break;
+		default:
+			flag = 0;
 		}
 		Mol.AddBond (start, end, order, flag);
 	}
@@ -827,14 +815,13 @@ bool Molecule::OnSignal (SignalId Signal, Object *Child)
 
 void Molecule::OpenCalc ()
 {
-	list<Atom*>::iterator ia, enda = m_Atoms.end ();
+	list<gcu::Atom*>::iterator ia, enda = m_Atoms.end ();
 	ostringstream ofs;
 	int nH;
-	// FIXME: the following line should be edited for stable releases
-	ofs << "gchemcalc-unstable ";
+	ofs << "gchemcalc-"API_VERSION" ";
 	for (ia = m_Atoms.begin(); ia != enda; ia++) {
 		ofs << (*ia)->GetSymbol();
-		nH = (*ia)->GetAttachedHydrogens ();
+		nH = reinterpret_cast <Atom *> (*ia)->GetAttachedHydrogens ();
 		if (nH > 0) {
 			ofs << "H" << nH;
 		}
@@ -845,22 +832,14 @@ void Molecule::OpenCalc ()
 void Molecule::CheckCrossings (Bond *pBond)
 {
 	View *pView = reinterpret_cast<Document*> (GetDocument ())->GetView ();
-	list<Bond*>::iterator i, iend = m_Bonds.end ();
+	list<gcu::Bond*>::iterator i, iend = m_Bonds.end ();
 	for (i = m_Bonds.begin (); i != iend; i++)
-		if (((*i) != pBond) && (*i)->IsCrossing (pBond)) {
+		if (((*i) != pBond) && reinterpret_cast <Bond *> (*i)->IsCrossing (pBond)) {
 			pView->Update (pBond);
 			pView->Update (*i);
 		}
 }
 
-void Molecule::Add (GtkWidget* w)
-{
-	/* Now that Object::Add adds children, we need to override this method
-	because a molecule children (atoms, bonds, and fragments) are added to
-	the widget by the document. FIXME! FIXME! FIXME! CHANGE THIS OLD WEIRD CODE!
-	*/
-}
-
 char const *Molecule::GetInChI ()
 {
 	if (m_Changed)
@@ -868,19 +847,19 @@ char const *Molecule::GetInChI ()
 	return m_InChI.c_str ();
 }
 
-std::string Molecule::GetRawFormula ()
+std::string Molecule::GetRawFormula () const
 {
 	ostringstream ofs;
 
 	if (!m_Fragments.size ()) {
-		// we do not support fragmentsat the moment
+		// we do not support fragments at the moment
 		map<string, int> elts;
-		list<Atom*>::iterator ia, enda = m_Atoms.end ();
+		list<gcu::Atom*>::const_iterator ia, enda = m_Atoms.end ();
 		for (ia = m_Atoms.begin(); ia != enda; ia++) {
 			if ((*ia)->GetZ () == 0)
 				continue;
 			elts[(*ia)->GetSymbol ()]++;
-			elts["H"] += (*ia)->GetAttachedHydrogens ();
+			elts["H"] += reinterpret_cast <Atom *> (*ia)->GetAttachedHydrogens ();
 		}
 		if (elts["C"] > 0) {
 			ofs << "C" << elts["C"];
@@ -898,4 +877,14 @@ std::string Molecule::GetRawFormula ()
 	return ofs.str ();
 }
 
+void Molecule::OnLoaded ()
+{
+	UpdateCycles ();
+}
+
+unsigned Molecule::GetAtomsNumber () const
+{
+	return m_Atoms.size () + m_Fragments.size ();
+}
+
 }	//	namespace gcp
