@@ -2,7 +2,7 @@
  * GChemPaint library
  * window.cc
  *
- * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -31,11 +31,9 @@
 #include "view.h"
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
-#include <libgnomeprintui/gnome-print-dialog.h>
-#include <libgnomeprintui/gnome-print-job-preview.h>
+#include <gcu/print-setup-dlg.h>
 #include <glib/gi18n-lib.h>
+#include <string>
 
 static void on_destroy (GtkWidget* widget, gcp::Window* Win)
 {
@@ -83,9 +81,19 @@ static void on_properties(GtkWidget* widget, gcp::Window* Win)
 	Win->OnProperties ();
 }
 
-void on_print(GtkWidget* widget, gcp::Window* Win)
+static void on_page_setup (GtkWidget *widget, gcp::Window* Win)
 {
-	Win->OnPrint ();
+	Win->OnPageSetup ();
+}
+
+static void on_print_preview (GtkWidget *widget, gcp::Window* Win)
+{
+	Win->GetDocument ()->Print (true);
+}
+
+static void on_file_print (GtkWidget *widget, gcp::Window* Win)
+{
+	Win->GetDocument ()->Print (false);
 }
 
 static void on_file_close (GtkWidget* widget, gcp::Window *Win)
@@ -198,6 +206,11 @@ static void on_mail (GtkWidget *widget, gcp::Window* Win)
 	Win->GetApplication ()->OnMail ("mailto:gchempaint-main@nongnu.org");
 }
 
+static void on_live_assistance (GtkWidget *widget, gcp::Window *Win)
+{
+	Win->GetApplication ()->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, gcp::Window* Win)
 {
 	Win->GetApplication ()->OnBug ();
@@ -278,8 +291,12 @@ static GtkActionEntry entries[] = {
 		  N_("Save the current file with a different name"), G_CALLBACK (on_file_save_as) },
 	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
 		  N_("Save the current file as an image"), G_CALLBACK (on_file_save_as_image) },
+	  { "PageSetup", NULL, N_("Page Set_up..."), NULL,
+		  N_("Setup the page settings for your current printer"), G_CALLBACK (on_page_setup) },
+	  { "PrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Pre_view"), NULL,
+		  N_("Print preview"), G_CALLBACK (on_print_preview) },
 	  { "Print", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
-		  N_("Print the current file"), G_CALLBACK (on_print) },
+		  N_("Print the current file"), G_CALLBACK (on_file_print) },
 	  { "Properties", GTK_STOCK_PROPERTIES, N_("Prope_rties..."), NULL,
 		  N_("Modify the file's properties"), G_CALLBACK (on_properties) },
 	  { "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -330,6 +347,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for GChemPaint"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("GChemPaint on the _web"), NULL,
 		  N_("Browse GChemPaint's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about GChemPaint"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -353,6 +372,8 @@ static const char *ui_description =
 "      <menuitem action='SaveAs'/>"
 "      <menuitem action='SaveAsImage'/>"
 "      <separator name='file-sep1'/>"
+"      <menuitem action='PageSetup'/>"
+"      <menuitem action='PrintPreview'/>"
 "      <menuitem action='Print'/>"
 "      <separator name='file-sep2'/>"
 "      <menuitem action='Properties'/>"
@@ -398,9 +419,10 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
@@ -413,34 +435,11 @@ static const char *ui_description =
 "  </toolbar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
+using namespace gcu;
 
 namespace gcp {
 
-Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
+Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui) throw (std::runtime_error):
 	Target (App)
 {
 	GtkWidget *vbox;
@@ -450,7 +449,6 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 	GtkAccelGroup *accel_group;
 	GError *error;
 
-	m_App = App;
 	SetWindow (window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL)));
 	g_object_set (G_OBJECT (window), "urgency-hint", false, NULL);
 	g_object_set_data (G_OBJECT (window), "gcp-role", (void*) 1);
@@ -473,17 +471,9 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 	
 	error = NULL;
 	if (!gtk_ui_manager_add_ui_from_string (m_UIManager, ui_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-		exit (EXIT_FAILURE);
-	}
-	if (App->HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (App->HasMailAgent () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
+		std::string what = std::string ("building menus failed: ") + error->message;
 		g_error_free (error);
+		throw std::runtime_error (what);
 	}
 	if (extra_ui && !gtk_ui_manager_add_ui_from_string (m_UIManager, extra_ui, -1, &error)) {
 		g_message ("building menus failed: %s", error->message);
@@ -498,6 +488,7 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 
 	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
 	gtk_recent_filter_add_mime_type (filter, "application/x-gchempaint");
 	gtk_recent_filter_add_mime_type (filter, "chemical/x-chemdraw");
@@ -550,7 +541,7 @@ Window::~Window ()
 
 void Window::OnFileNew()
 {
-	m_App->OnFileNew ();
+	m_Application->OnFileNew ();
 }
 
 void Window::OnSave()
@@ -558,12 +549,12 @@ void Window::OnSave()
 	if (m_Document->GetFileName ())
 		m_Document->Save();
 	else
-		m_App->OnSaveAs ();
+		m_Application->OnSaveAs ();
 }
 
 void Window::OnFileOpen()
 {
-	FileChooser (m_App, false, m_App->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
+	FileChooser (m_Application, false, m_Application->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
 }
 
 void Window::OnProperties()
@@ -571,48 +562,6 @@ void Window::OnProperties()
 	m_Document->OnProperties ();
 }
 
-void Window::OnPrint()
-{
-	GnomePrintConfig* config = gnome_print_config_default ();
-	GnomePrintContext *pc;// = gnome_print_context_new (config);
-	GnomePrintJob *gpj = gnome_print_job_new (config);
-	int do_preview = 0, copies = 1, collate = 0;
-	GnomePrintDialog *gpd;
-	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)_("Print"), GNOME_PRINT_DIALOG_COPIES));
-	gtk_window_set_icon_name (GTK_WINDOW (gpd), "gchempaint");
-	gnome_print_dialog_set_copies (gpd, copies, collate);
-	switch (gtk_dialog_run (GTK_DIALOG (gpd))) {
-	case GNOME_PRINT_DIALOG_RESPONSE_PRINT:
-		do_preview = 0;
-		break;
-	case GNOME_PRINT_DIALOG_RESPONSE_PREVIEW:
-		do_preview = 1;
-		break;
-	case GNOME_PRINT_DIALOG_RESPONSE_CANCEL:
-		gtk_widget_destroy (GTK_WIDGET (gpd));
-		return;
-	}
-	gtk_widget_destroy (GTK_WIDGET (gpd));
-	pc = gnome_print_job_get_context (gpj);
-	gnome_print_beginpage (pc, (const guchar*)"");
-	gdouble width, height;
-	gnome_print_config_get_double (config, (guchar const*) GNOME_PRINT_KEY_PAPER_WIDTH, &width);
-	gnome_print_config_get_double (config, (guchar const*) GNOME_PRINT_KEY_PAPER_HEIGHT, &height);
-	m_Document->Print (pc, width, height);
-	gnome_print_showpage (pc);
-	g_object_unref (pc);
-	gnome_print_job_close (gpj);
-	if (do_preview) {
-		GtkWidget *preview = gnome_print_job_preview_new (gpj, (const guchar*)_("Preview"));
-		gtk_window_set_icon_name (GTK_WINDOW (preview), "gchempaint");
-		gtk_widget_show (preview);
-	} else {
-		gnome_print_job_print (gpj);
-	}
-	g_object_unref (gpj);
-	gnome_print_config_unref (config);
-}
-
 void Window::SetActive (gcp::Document* pDoc, GtkWidget* w)
 {
 }
@@ -754,21 +703,28 @@ bool Window::VerifySaved ()
 {
 	if (!m_Document->GetDirty ())
 		return true;
-	gchar* str = g_strdup_printf(_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
-	GtkWidget* mbox;
 	int res;
+	GtkWidget* mbox;
 	do {
+		gchar* str = g_strdup_printf (_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
 		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+		g_free (str);
 		gtk_dialog_add_button (GTK_DIALOG (mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		res = gtk_dialog_run (GTK_DIALOG (mbox));
 		gtk_widget_destroy (mbox);
 		if (res == GTK_RESPONSE_YES)
 			OnSave ();
+		while (gtk_events_pending ()) // no idea why this is needed
+			gtk_main_iteration ();
 	} while ((res == GTK_RESPONSE_YES) && (m_Document->GetFileName () == NULL));
 	if (res == GTK_RESPONSE_NO)
 		m_Document->SetDirty (false);
-	g_free(str);
 	return (res != GTK_RESPONSE_CANCEL);
 }
 
+void Window::OnPageSetup ()
+{
+	new PrintSetupDlg (m_Application, m_Document);
+}
+
 } // namespace gcp
