@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * bond.h 
  *
- * Copyright (C) 2002-2008 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -203,11 +203,16 @@ as second argument.
 @param oldAtom the atom to replace.
 @param newAtom the new atom.
 
-To sucess, this needs that the new atom can accpt all the bonds from the old one.
+To sucess, this needs that the new atom can accept all the bonds from the old one.
 @return true on success.
 */
 	bool ReplaceAtom (Atom* oldAtom, Atom* newAtom);
 
+/*!
+This method should be called when a bond has been fully loaded.
+*/
+	void OnLoaded ();
+
 protected:
 /*!
 The order of the bond.
