@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * cmd-context.h 
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,13 +23,30 @@
 #ifndef GCU_CMD_CONTEXT_H
 #define GCU_CMD_CONTEXT_H
 
-#include <goffice/app/go-cmd-context-impl.h>
+#ifdef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#else
+#   include <goffice/app/go-cmd-context-impl.h>
+#endif
 #include <glib-object.h>
 
 G_BEGIN_DECLS
 
+/*!\file
+Declaration of the GcuCmdContext structure, a GObject implementing the
+GOCmdContext interface from goffice. This is mandatory to be able to edit
+charts.
+*/
+
+/*!
+@return the GType associated to GcuCmdContext.
+*/
 #define GCU_CMD_CONTEXT_TYPE		(gcu_cmd_context_get_type ())
 GType		gcu_cmd_context_get_type   (void);
+
+/*!
+@return a static global GcuCmdContext instance.
+*/
 GOCmdContext *gcu_get_cmd_context (void);
 
 G_END_DECLS
