@@ -23,7 +23,11 @@
 #include "config.h"
 #include "element.h"
 #include "xml-utils.h"
-#include <goffice/math/go-math.h>
+#ifdef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#else
+#   include <goffice/math/go-math.h>
+#endif
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -44,8 +48,8 @@ static set<string>units;
 
 static void ReadValue (char const *source, GcuValue &value)
 {
-	char *buf, *dot;
-	value.value = strtod (source, &buf);
+	const char *buf, *dot;
+	value.value = strtod (source, const_cast <char**> (&buf));
 	dot = strchr (source, '.');
 	value.prec = (dot)? buf - dot - 1: 0;
 	value.delta = (*buf == '(')? strtol (buf + 1, NULL, 10): 0;
@@ -53,8 +57,8 @@ static void ReadValue (char const *source, GcuValue &value)
 
 static void ReadDimensionalValue (char const *source, GcuDimensionalValue &value)
 {
-	char *buf, *dot;
-	value.value = strtod (source, &buf);
+	const char *buf, *dot;
+	value.value = strtod (source, const_cast <char**> (&buf));
 	dot = strchr (source, '.');
 	value.prec = (dot)? buf - dot - 1: 0;
 	value.delta = (*buf == '(')? strtol (buf + 1, NULL, 10): 0;
@@ -84,9 +88,7 @@ EltTable Table;
 EltTable::EltTable()
 {
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-#ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
 	xmlDocPtr xml;
 	char* DefaultName;
 	char *lang = getenv ("LANG");
