@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * element.h 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,10 +33,16 @@
 #include "isotope.h"
 #include "value.h"
 
+/*!\file */ 
+/*!\def GCU_ERROR
+Defines a standard error value.
+*/
 #define GCU_ERROR (1 << (sizeof(int) - 1))
 
 /*!\namespace gcu
-The namespace used for all C++ classes provided by the Gnome Chemistry Utils.
+\brief The Gnome Chemistry Utils C++ classes
+
+The namespace used for all C++ classes provided by the Gnome Chemistry Utils base library.
 */
 namespace gcu
 {
@@ -179,7 +185,7 @@ public:
 	*/
 	bool GetBestSide () {return m_BestSide;}
 	/*!
-	Retreives the default color used for the element.
+	Retrieves the default color used for the element.
 	@return an array of three double values for the red, green and blue components of the color.
 	*/
 	double* GetDefaultColor () {return m_DefaultColor;}
