@@ -26,14 +26,21 @@
 #include "cmd-context.h"
 #include "document.h"
 #include "loader.h"
-#include <goffice/app/error-info.h>
-#include <goffice/app/go-plugin-service.h>
-#include <goffice/app/go-plugin-service-impl.h>
-#include <goffice/app/go-plugin-loader-module.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/app/error-info.h>
+#   include <goffice/app/go-plugin-service.h>
+#   include <goffice/app/go-plugin-service-impl.h>
+#   include <goffice/app/go-plugin-loader-module.h>
+#endif
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <cstring>
 
+#ifndef GO_TYPE_PLUGIN_SERVICE_SIMPLE
+#   define GO_TYPE_PLUGIN_SERVICE_SIMPLE GO_PLUGIN_SERVICE_SIMPLE_TYPE
+#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
+#endif
+
 using namespace std;
 
 namespace gcu {
@@ -89,6 +96,8 @@ plugin_service_chemical_loader_read_xml (GOPluginService * service, xmlNode * tr
 						l.supports3D = true;
 					if (strchr (prop, 'c') != NULL || strchr (prop, 'C'))
 						l.supportsCrystals = true;
+					if (strchr (prop, 's') != NULL || strchr (prop, 'C'))
+						l.supportsSpectra = true;
 					xmlFree (prop);
 				}
 				loaders[name] = l;
@@ -120,7 +129,7 @@ plugin_service_chemical_loader_init (PluginServiceChemicalLoader *s)
 
 GSF_CLASS (PluginServiceChemicalLoader, plugin_service_chemical_loader,
            plugin_service_chemical_loader_class_init, plugin_service_chemical_loader_init,
-           GO_PLUGIN_SERVICE_SIMPLE_TYPE)
+           GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 
 Loader::Loader ()
 {
@@ -141,9 +150,8 @@ void Loader::Init ()
 	go_plugin_loader_module_register_version ("gchemutils", VERSION);
 	char *plugins_dir = g_strdup (GCU_PLUGINS_DIR);
 	GSList *dirs = g_slist_prepend (NULL, plugins_dir);
-	go_plugins_init (gcu_get_cmd_context (), NULL, NULL, dirs, true, GO_PLUGIN_LOADER_MODULE_TYPE);
-	g_slist_free (dirs);
-	g_free (plugins_dir);
+	go_plugins_init (gcu_get_cmd_context (), NULL, NULL, dirs, true, GO_TYPE_PLUGIN_LOADER_MODULE);
+	// do not free dirs and plugins_dir, goffice will
 	Inited = true;
 }
 
