@@ -59,6 +59,20 @@ public:	\
 private:	\
 	type m_##member;
 
+/*!\def GCU_POINTER_PROP()
+Defines a private pointer member with appropriate get/set methods.
+GCU_POINTER_PROP((Type,Foo) expands to one private member:
+\code
+	Type *m_Foo;
+\endcode
+
+and three public methods:
+\code
+	void SetFoo(Type *val);
+	Type *GetFoo();
+	Type const *GetFoo() const;
+\endcode
+*/
 #define GCU_POINTER_PROP(type,member) \
 public:	\
 	void Set##member (type *val) {m_##member = val;}	\
@@ -68,7 +82,7 @@ private:	\
 	type *m_##member;
 
 /*!\def GCU_RO_PROP()
-Defines a private member with appropriate get method. RO stands for Read Only. The member
+Defines a private member with an appropriate get method. RO stands for Read Only. The member
 can't be modified from outside the class it belongs too or a friend class.
 GCU_RO_PROP(Type,Foo) expands to one private member:
 \code
@@ -86,6 +100,19 @@ public:	\
 private:	\
 	type m_##member;
 
+/*!\def GCU_RO_POINTER_PROP()
+Defines a private pointer member an with appropriate get method. RO stands for Read Only. The member
+can't be modified from outside the class it belongs too or a friend class.
+GCU_RO_POINTER_PROP((Type,Foo) expands to one private member:
+\code
+	Type *m_Foo;
+\endcode
+
+and one public methods:
+\code
+	Type const *GetFoo() const;
+\endcode
+*/
 #define GCU_RO_POINTER_PROP(type,member) \
 public:	\
 	type const *Get##member (void) const {return m_##member;}	\
@@ -93,7 +120,7 @@ private:	\
 	type *m_##member;
 
 /*!\def GCU_PROT_PROP()
-Defines a protected member with appropriate get method. The member can be modified
+Defines a protected member with an appropriate get method. The member can be modified
 the class it belongs too or a friend class or a derived class.
 GCU_PROT_PROP(Type,Foo) expands to one protected member:
 \code
@@ -111,6 +138,21 @@ public:	\
 protected:	\
 	type m_##member;
 
+/*!\def GCU_PROT_POINTER_PROP()
+Defines a private pointer member with an appropriate get method. The member can be modified
+the class it belongs too or a friend class or a derived class. The data referenced
+by the pointer can be modified if the class instance is not const.
+GCU_PROT_POINTER_PROP((Type,Foo) expands to one private member:
+\code
+	Type *m_Foo;
+\endcode
+
+and two public methods:
+\code
+	Type *GetFoo();
+	Type const *GetFoo() const;
+\endcode
+*/
 #define GCU_PROT_POINTER_PROP(type,member) \
 public:	\
 	type *Get##member (void) {return m_##member;}	\
@@ -122,8 +164,11 @@ protected:	\
 This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs or if the value is 0,
 \a defaultval is used instead.\n
-Calling class must have a GConfClient member called m_ConfClient, and the code
-must provide a GError *error initially set to NULL.
+If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
+have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
+member called m_ConfClient, and the code must provide a GError *error initially
+set to NULL (GConf version only).
+The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #ifdef HAVE_GO_CONF_SYNC
 #define go_conf_get_float go_conf_get_double
@@ -146,8 +191,11 @@ must provide a GError *error initially set to NULL.
 /*!\def GCU_GCONF_GET_NO_CHECK()
 This macro gets the numerical value of type \a type associated to \a key, and
 copies it to \a target. If an error occurs, \a defaultval is used instead.\n
-Calling class must have a GConfClient member called m_ConfClient, and the code
-must provide a GError *error initially set to NULL.
+If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
+have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
+member called m_ConfClient, and the code must provide a GError *error initially
+set to NULL (GConf version only).
+The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_NO_CHECK(key,type,target,defaultval) \
@@ -168,8 +216,11 @@ This macro gets the numerical value of type \a type associated to \a key. If an
 occurs or if the value is 0, \a defaultval is used instead.\n
 The resuting value (which might be the default value) is then passed
 to \a func and the result is copied to \a target. \n
-Calling class must have a GConfClient member called m_ConfClient, and the code
-must provide a GError *error initially set to NULL.
+If the GOConf mechanism is available in goffice (>= 0.7.0), calling class must
+have a GOConfNode called m_ConfNode or, for older GOffice versions, a GConfClient
+member called m_ConfClient, and the code must provide a GError *error initially
+set to NULL (GConf version only).
+The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_N_TRANSFORM(key,type,target,defaultval,func) \
@@ -202,6 +253,7 @@ If \a target is not NULL when entering the macro, it is deallocated using g_free
 and set to NULL before calling gconf_client_get_string.\n
 Calling class must have a GConfClient member called m_ConfClient, and the code
 must provide a GError *error initially set to NULL.
+The real key is obtained by appending the value of ROOTDIR to \a key.
 */
 #ifdef HAVE_GO_CONF_SYNC
 #define GCU_GCONF_GET_STRING(key,target,defaultval) \
@@ -229,6 +281,13 @@ must provide a GError *error initially set to NULL.
 			target = g_strdup (defaultval);
 #endif
 
+/*!\def GCU_UPDATE_KEY()
+This macro updates a value of type \a type associated to \a key, and
+copies it to \a target. \a action is called after setting the target?
+It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
+on the GOffice library version.
+The real key is obtained by appending the value of ROOTDIR to \a key.
+*/
 #ifdef HAVE_GO_CONF_SYNC
 #define GCU_UPDATE_KEY(key,type,target,action) \
 	if (!strcmp (name, ROOTDIR key)) { \
@@ -245,6 +304,13 @@ must provide a GError *error initially set to NULL.
 	}
 #endif
 
+/*!\def GCU_UPDATE_STRING_KEY()
+This macro updates a string value associated to \a key, and
+copies it to \a target. \a action is called after setting the target?
+It also needs either a GOConfNode* called node or a GConfEntry alled entry, depending
+on the GOffice library version.
+The real key is obtained by appending the value of ROOTDIR to \a key.
+*/
 #ifdef HAVE_GO_CONF_SYNC
 #define GCU_UPDATE_STRING_KEY(key,target,action) \
 	if (!strcmp (name, ROOTDIR key)) { \
