@@ -26,7 +26,11 @@
 #include "document.h"
 #include "macros.h"
 #include "printable.h"
-#include <goffice/graph/gog-series.h>
+#ifdef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#else
+#   include <goffice/graph/gog-series.h>
+#endif
 #include <string>
 #include <vector>
 
@@ -349,7 +353,7 @@ private:
 	std::vector <JdxVar> variables;
 	int X, Y, R, I, integral, Rt, It, Rp;
 	double freq;
-	double offset;
+	double offset, refpoint;
 	GtkWidget *m_XAxisInvertBtn;
 	guint m_XAxisInvertSgn;
 
