@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -31,8 +31,10 @@
 #include <gcp/view.h>
 #include <gcp/widgetdata.h>
 #include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/app/go-plugin.h>
+#   include <goffice/app/go-plugin-loader-module.h>
+#endif
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
@@ -47,6 +49,10 @@
 #include <string>
 #include <cstring>
 
+#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
+#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
+#endif
+
 using namespace std;
 using namespace gcu;
 
@@ -99,6 +105,7 @@ ChemComp::ChemComp (void* instance, string& mime_type)
 	Plug = NULL;
 	Doc = NULL;
 	gcpApp = NULL;
+	Viewer = NULL;
 }
 
 ChemComp::~ChemComp ()
@@ -111,6 +118,8 @@ ChemComp::~ChemComp ()
 void ChemComp::SetWindow (XID xid)
 {
 	int width, height;
+	if (Viewer)
+		return;
 	if (Xid == xid) {
 		//just resize and redraw
 		gdk_window_get_geometry (Parent, NULL, NULL, &width, &height, NULL);
@@ -134,6 +143,7 @@ void ChemComp::SetWindow (XID xid)
 			if (!gcpApp)
 				gcpApp = new MozPaintApp ();
 			Doc = new gcp::Document (gcpApp, true, NULL);
+			Doc->SetEditable (false);
 			Viewer = Doc->GetView ()->CreateNewWidget ();
 		} else 	if (MimeType == "chemical/x-jcamp-dx")
 			Viewer = gtk_spectrum_viewer_new (NULL);
@@ -146,6 +156,8 @@ void ChemComp::SetWindow (XID xid)
 
 void ChemComp::SetFilename (string& filename)
 {
+	if (Filename.length ())
+		return;
 	Filename = filename;
 	if (MimeType == "application/x-gcrystal") {
 		if (!loaded_radii) {
@@ -299,7 +311,7 @@ int main (int argc, char *argv[])
 	}
 #endif
 	libgoffice_init ();
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	in_channel = g_io_channel_unix_new (fileno (stdin));
 	g_io_add_watch (in_channel, G_IO_IN, io_func, &error);
 	gtk_main ();
