@@ -603,7 +603,7 @@ static void
 cdxml_graphic_start (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	CDXMLReadState	*state = (CDXMLReadState *) xin->user_state;
-	guint32 Id;
+	guint32 Id = 0;
 	guint16 type = 0xffff, arrow_type = 0xffff;
 	double x0, y0, x1, y1;
 	while (*attrs) {
@@ -793,9 +793,7 @@ G_MODULE_EXPORT void
 go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 {
 	bindtextdomain (GETTEXT_PACKAGE, DATADIR"/locale");
-#ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
 }
 
 G_MODULE_EXPORT void
