@@ -89,7 +89,9 @@ bool WikipediaApp::FileProcess (const gchar* filename, const gchar* mime_type, b
 	bool err = g_file_query_exists (file, NULL);
 	gint result = GTK_RESPONSE_YES;
 	if (err) {
-		gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename2);
+		char *buf = g_uri_unescape_string (filename2, NULL);
+		gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), buf);
+		g_free (buf);
 		GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 		gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 		result = gtk_dialog_run (Box);
@@ -101,7 +103,9 @@ bool WikipediaApp::FileProcess (const gchar* filename, const gchar* mime_type, b
 			// destroy the old file
 			g_file_delete (file, NULL, &error);
 			if (error) {
-				gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), filename2, error->message);
+				char *buf = g_uri_unescape_string (filename2, NULL);
+				gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), buf, error->message);
+				g_free (buf);
 				g_error_free (error);
 				GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 				gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
@@ -171,7 +175,7 @@ bool WikipediaApp::FileProcess (const gchar* filename, const gchar* mime_type, b
 		values.push_back (const_cast<char*> (InChI));
 		keys.push_back (reinterpret_cast<char*> (NULL));
 		values.push_back (reinterpret_cast<char*> (NULL));
-		gdk_pixbuf_save_to_callbackv (alpha, do_save_image, output, "png", keys.data (), values.data (), &error);
+		gdk_pixbuf_save_to_callbackv (alpha, do_save_image, output, "png", &keys[0], &values[0], &error);
 		g_output_stream_close (output, NULL, NULL); // hope there will be no error there
 	}
 	if (error) {
