@@ -28,7 +28,11 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#include <goffice/utils/go-image.h>
+#ifdef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#else
+#   include <goffice/utils/go-image.h>
+#endif
 #include <gsf/gsf-output-gio.h>
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
@@ -41,30 +45,30 @@ gc3dApplication::gc3dApplication (Display3DMode display3d, char const *bg):
 	Application (_("GChem3D Viewer"), DATADIR, "gchem3d"),
 	m_Display3D (display3d)
 {
-	if (bg) {
-		if (!strcmp (bg, "black")) {
-			m_Red = 0.;
-			m_Green = 0.;
-			m_Blue = 0.;
-		} else if (!strcmp (bg, "white")) {
-			m_Red = 0.;
-			m_Green = 0.;
-			m_Blue = 0.;
-		} else {
-			if ((strlen (bg) != 7) || (*bg != '#')) {
-				g_warning ("Unrecognized color: %s\n", bg);
-				return;
-			}
-			int r, g, b;
-			r = strtoul (bg + 1, NULL, 16);
-			b = r & 0xff;
-			m_Blue = (float) b / 255.;
-			r >>= 8;
-			g = r & 0xff;
-			m_Green = (float) g / 255.;
-			r >>=8;
-			m_Red = (float) r / 255;
+	if (!bg)
+		bg = "black";
+	if (!strcmp (bg, "black")) {
+		m_Red = 0.;
+		m_Green = 0.;
+		m_Blue = 0.;
+	} else if (!strcmp (bg, "white")) {
+		m_Red = 1.;
+		m_Green = 1.;
+		m_Blue = 1.;
+	} else {
+		if ((strlen (bg) != 7) || (*bg != '#')) {
+			g_warning ("Unrecognized color: %s\n", bg);
+			return;
 		}
+		int r, g, b;
+		r = strtoul (bg + 1, NULL, 16);
+		b = r & 0xff;
+		m_Blue = (float) b / 255.;
+		r >>= 8;
+		g = r & 0xff;
+		m_Green = (float) g / 255.;
+		r >>=8;
+		m_Red = (float) r / 255;
 	}
 }
 
@@ -163,7 +167,9 @@ bool gc3dApplication::FileProcess (const gchar* filename, const gchar* mime_type
 		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename2.c_str ());
+			char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
