@@ -37,34 +37,46 @@
 #include <gcu/value.h>
 #include <glib/gi18n.h>
 #include <glade/glade.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkclipboard.h>
-#include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
-#include <goffice/data/go-data-simple.h>
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-data-set.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-image.h>
-#include <goffice/utils/go-line.h>
-#include <goffice/utils/go-marker.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <gtk/gtkmain.h>
+#   include <gtk/gtkentry.h>
+#   include <gtk/gtklabel.h>
+#   include <gtk/gtkmessagedialog.h>
+#   include <gtk/gtkuimanager.h>
+#   include <gtk/gtkaboutdialog.h>
+#   include <gtk/gtkstock.h>
+#   include <gtk/gtkbox.h>
+#   include <gtk/gtktreeview.h>
+#   include <gtk/gtkcellrenderertext.h>
+#   include <gtk/gtkclipboard.h>
+#   include <goffice/goffice.h>
+#   include <goffice/app/go-plugin.h>
+#   include <goffice/app/go-plugin-loader-module.h>
+#   include <goffice/data/go-data-simple.h>
+#   include <goffice/gtk/go-graph-widget.h>
+#   include <goffice/gtk/goffice-gtk.h>
+#   include <goffice/graph/gog-axis.h>
+#   include <goffice/graph/gog-data-set.h>
+#   include <goffice/graph/gog-object.h>
+#   include <goffice/graph/gog-plot.h>
+#   include <goffice/graph/gog-series.h>
+#   ifndef GO_TYPE_PLUGIN_LOADER_MODULE
+#      define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
+#      include <goffice/graph/gog-style.h>
+#      include <goffice/graph/gog-styled-object.h>
+#      define GOStyle GogStyle
+#      define go_styled_object_get_style gog_styled_object_get_style
+#      define GO_STYLED_OBJECT GOG_STYLED_OBJECT
+#   else
+#      include <goffice/graph/gog-object-xml.h>
+#      include <goffice/utils/go-style.h>
+#      include <goffice/utils/go-styled-object.h>
+#   endif
+#   include <goffice/utils/go-locale.h>
+#   include <goffice/utils/go-image.h>
+#   include <goffice/utils/go-line.h>
+#   include <goffice/utils/go-marker.h>
+#endif
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
@@ -228,7 +240,9 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename);
+			char *unescaped = g_uri_unescape_string (filename, NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
 			result = gtk_dialog_run (Box);
@@ -262,7 +276,7 @@ GChemCalc *App;
 
 static void on_quit (GtkWidget *widget, void *data)
 {
-	gtk_main_quit();
+	gtk_widget_destroy (GTK_WIDGET (App->window));
 }
 
 static void on_help (GtkWidget *widget, gpointer data)
@@ -300,7 +314,7 @@ static void on_about (GtkWidget *widget, void *data)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemCalc is a simple calculator for chemists");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2007 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -510,7 +524,11 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
+#ifdef HAVE_GO_DATA_SERIALIZE
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
+#else
 			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+#endif
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
@@ -670,7 +688,7 @@ static const char *ui_description =
 "      <menuitem action='Guess'/>"
 "      <menuitem action='Atom'/>"
 "      <menuitem action='Residue'/>"
-"      <menuitem action='Ask'/>"
+//"      <menuitem action='Ask'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
@@ -734,7 +752,7 @@ int main (int argc, char *argv[])
 	App = new GChemCalc ();
 	
 	/* Initialize plugins manager */
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
 	GladeXML *xml =  glade_xml_new (GLADEDIR"/gchemcalc.glade", "gchemcalc", NULL);
 	App->window = GTK_WINDOW (glade_xml_get_widget (xml, "gchemcalc"));
@@ -792,11 +810,7 @@ int main (int argc, char *argv[])
 	App->mono = GTK_LABEL (glade_xml_get_widget (xml, "mono"));
 	App->monomass = GTK_LABEL (glade_xml_get_widget (xml, "monomass"));
 	App->pattern_page = glade_xml_get_widget (xml, "pattern");
-#ifdef GO_GRAPH_WIDGET_OLD_API
-	App->graph_widget = go_graph_widget_new ();
-#else
 	App->graph_widget = go_graph_widget_new (NULL);
-#endif
 	gtk_widget_show (App->graph_widget);
 	gtk_box_pack_end (GTK_BOX (App->pattern_page), App->graph_widget, TRUE, TRUE, 0);
 	App->graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (App->graph_widget));
@@ -806,7 +820,7 @@ int main (int argc, char *argv[])
 	// Create a series for the plot and populate it with some simple data
 	App->series = gog_plot_new_series (App->plot);
 	gog_object_add_by_name (GOG_OBJECT (App->series), "Vertical drop lines", NULL);
-	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (App->series));
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (App->series));
 	go_marker_set_shape (style->marker.mark, GO_MARKER_NONE);
 	style->marker.auto_shape = false;
 	style->line.dash_type = GO_LINE_NONE;
