@@ -28,14 +28,16 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/print-setup-dlg.h>
-#include <goffice/gtk/go-graph-widget.h>
-#include <goffice/graph/gog-object-xml.h>
-#include <goffice/utils/go-locale.h>
-#include <goffice/utils/go-image.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/gtk/go-graph-widget.h>
+#   include <goffice/graph/gog-object-xml.h>
+#   include <goffice/utils/go-locale.h>
+#   include <goffice/utils/go-image.h>
+#   include <gtk/gtkbox.h>
+#   include <gtk/gtkcontainer.h>
+#   include <gtk/gtkwindow.h>
+#endif
 #include <gsf/gsf-output-memory.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtkwindow.h>
 #include <glib/gi18n.h>
 
 using namespace std;
@@ -320,7 +322,11 @@ static void on_get_data (GtkClipboard *clipboard, GtkSelectionData *selection_da
 			go_locale_untranslated_booleans ();
 		
 			xout = gsf_xml_out_new (output);
+#ifdef HAVE_GO_DATA_SERIALIZE
+			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
+#else
 			gog_object_write_xml_sax (GOG_OBJECT (graph), xout);
+#endif
 			g_object_unref (xout);
 		
 			/* go_setlocale restores bools to locale translation */
