@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-app.cc 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -29,6 +29,7 @@
 #include "gchemtable-elt.h"
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
+#include <gcu/filechooser.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtkaboutdialog.h>
@@ -36,9 +37,13 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtkwindow.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
 #include <cstdlib>
 #include <cstring>
+#include <list>
+#include <string>
+
+using namespace std;
 
 static void on_quit (GtkWidget *widget, GChemTableApp *App)
 {
@@ -93,10 +98,7 @@ static void on_block_colors (GtkWidget *widget, GChemTableApp *App)
 
 static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
 {
-	GnomeVFSResult error = gnome_vfs_url_show(url);
-	if (error != GNOME_VFS_OK) {
-		g_print("GnomeVFSResult while trying to launch URL in about dialog: error %u\n", error);
-	}
+	reinterpret_cast <Application *> (data)->OnWeb (url);
 }
 
 static void on_help (GtkWidget *widget, GChemTableApp *app)
@@ -114,6 +116,11 @@ static void on_mail (GtkWidget *widget, GChemTableApp *app)
 	app->OnMail ();
 }
 
+static void on_live_assistance (GtkWidget *widget, GChemTableApp *app)
+{
+	app->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, GChemTableApp *app)
 {
 	app->OnBug ();
@@ -164,6 +171,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for the Periodic Table"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("Gnome Chemistry Utils on the _web"), NULL,
 		  N_("Browse the Gnome Chemistry Utils's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about the Gnome Chemistry Utils"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -195,39 +204,15 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 static void get_state_color (int Z, GdkColor *color, GChemTableApp *App)
 {
 	App->GetStateColor (Z, color);
@@ -301,14 +286,6 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable")
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (HasMailAgent () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
 	periodic = GTK_PERIODIC (gtk_periodic_new());
@@ -371,7 +348,7 @@ void GChemTableApp::OnAbout ()
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemTable is a chemical periodic table of the elements application");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2007 Jean Bréfort");
+	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -383,10 +360,10 @@ void GChemTableApp::OnAbout ()
 		"GNU General Public License for more details.\n\n"
 		"You should have received a copy of the GNU General Public License\n"
 		"along with this program; if not, write to the Free Software\n"
-		"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307\n"
+		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301\n"
 		"USA";
 	
-	gtk_about_dialog_set_url_hook(on_about_activate_url, NULL, NULL);
+	gtk_about_dialog_set_url_hook (on_about_activate_url, this, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -673,3 +650,49 @@ void GChemTableApp::OnNewChart ()
 {
 	new GChemTableCurve (this, NULL);
 }
+
+void GChemTableApp::OnSaveAsImage (GChemTableCurve *curve)
+{
+	if (!curve)
+		return;
+	list<string> l;
+	char const *mime;
+	map<string, GdkPixbufFormat*>::iterator i, end = m_SupportedPixbufFormats.end ();
+	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
+		l.push_front ((*i).first.c_str ());
+	if (go_image_get_format_from_name ("eps") != GO_IMAGE_FORMAT_UNKNOWN) {
+		mime = go_image_format_to_mime ("eps");
+		if (mime)
+			l.push_front (mime);
+	}
+	l.push_front ("application/postscript");
+	l.push_front ("application/pdf");
+	l.push_front ("image/svg+xml");
+	FileChooser (this, true, l, reinterpret_cast <Document *> (curve), _("Save as image"), GetImageSizeWidget ());
+}
+
+bool GChemTableApp::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *Doc)
+{
+	GChemTableCurve *curve = reinterpret_cast <GChemTableCurve *> (Doc);
+	if(bSave) {
+		GFile *file = g_file_new_for_uri (filename);
+		bool err = g_file_query_exists (file, NULL);
+		gint result = GTK_RESPONSE_YES;
+		if (err) {
+			char *unescaped = g_uri_unescape_string (filename, NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
+			result = gtk_dialog_run (Box);
+			gtk_widget_destroy (GTK_WIDGET (Box));
+			g_free (message);
+		}
+		if (result == GTK_RESPONSE_YES) {
+			g_file_delete (file, NULL, NULL);
+			curve->SaveAsImage (filename, mime_type, GetImageWidth (), GetImageHeight ());
+		}
+		g_object_unref (file);
+	}
+	return false;
+}
