@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -25,10 +25,18 @@
 #include <gcu/element.h>
 #include <map>
 #include <string>
-#include <goffice/math/go-math.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/math/go-math.h>
+#endif
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n.h>
 
+#ifndef GO_TYPE_DATA_SCALAR
+#   define GO_TYPE_DATA_SCALAR GO_DATA_SCALAR_TYPE
+#   define GO_TYPE_DATA_VECTOR GO_DATA_VECTOR_TYPE
+#   define GO_TYPE_DATA_MATRIX GO_DATA_MATRIX_TYPE
+#endif
+
 using namespace std;
 static map <string, GOData *> GctScalars, GctVectors, GctMatrices;
 
@@ -54,13 +62,21 @@ gct_data_preferred_fmt (GOData const *dat)
 }
 
 static char *
+#ifdef HAVE_GO_DATA_SERIALIZE
+gct_data_serialize (GOData const *dat, gpointer data)
+#else
 gct_data_as_str (GOData const *dat)
+#endif
 {
 	return NULL;
 }
 
 static  gboolean
+#ifdef HAVE_GO_DATA_SERIALIZE
+gct_data_unserialize (GOData *dat, char const *str, gpointer data)
+#else
 gct_data_from_str (GOData *dat, char const *str)
+#endif
 {
 	return FALSE;
 }
@@ -101,8 +117,13 @@ gct_data_scalar_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
+#ifdef HAVE_GO_DATA_SERIALIZE
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
+#else
 	godata_klass->as_str = gct_data_as_str;
 	godata_klass->from_str = gct_data_from_str;
+#endif
 	scalar_klass->get_value = gct_data_scalar_get_value;
 	scalar_klass->get_str = gct_data_scalar_get_str;
 }
@@ -114,11 +135,11 @@ gct_data_scalar_init (GObject *obj)
 
 GSF_CLASS (GctDataScalar, gct_data_scalar,
 	   gct_data_scalar_class_init, gct_data_scalar_init,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 void gct_data_scalar_new (char const *name, void (*loader) (double *value))
 {
-	GctDataScalar *sc = GCT_DATA_SCALAR (g_object_new (GO_DATA_SCALAR_TYPE, NULL));
+	GctDataScalar *sc = GCT_DATA_SCALAR (g_object_new (GCT_DATA_SCALAR_TYPE, NULL));
 	sc->loader = loader;
 	GctScalars[name] = GO_DATA (sc);
 
@@ -169,6 +190,7 @@ gct_data_vector_load_values (GODataVector *dat)
 	if (dat->len > 0) {
 		int i = 0;
 		while (!go_finite (vec->data[i++]) && i < dat->len);
+		i--;
 		if (i < dat->len)
 			dat->minimum = dat->maximum = vec->data[i];
 		for (; i < dat->len; i++)
@@ -227,8 +249,13 @@ gct_data_vector_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
+#ifdef HAVE_GO_DATA_SERIALIZE
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
+#else
 	godata_klass->as_str = gct_data_as_str;
 	godata_klass->from_str = gct_data_from_str;
+#endif
 	vector_klass->load_len = gct_data_vector_load_len;
 	vector_klass->load_values = gct_data_vector_load_values;
 	vector_klass->get_value = gct_data_vector_get_value;
@@ -242,7 +269,7 @@ gct_data_vector_init (GObject *obj)
 
 GSF_CLASS (GctDataVector, gct_data_vector,
 	   gct_data_vector_class_init, gct_data_vector_init,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 void gct_data_vector_new (char const *name, void (*loader) (double **values, int *length))
 {
@@ -331,8 +358,13 @@ gct_data_matrix_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
+#ifdef HAVE_GO_DATA_SERIALIZE
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
+#else
 	godata_klass->as_str = gct_data_as_str;
 	godata_klass->from_str = gct_data_from_str;
+#endif
 	matrix_klass->load_size = gct_data_matrix_load_size;
 	matrix_klass->load_values = gct_data_matrix_load_values;
 	matrix_klass->get_value = gct_data_matrix_get_value;
@@ -346,7 +378,7 @@ gct_data_matrix_init (GObject *obj)
 
 GSF_CLASS (GctDataMatrix, gct_data_matrix,
 	   gct_data_matrix_class_init, gct_data_matrix_init,
-	   GO_DATA_MATRIX_TYPE)
+	   GO_TYPE_DATA_MATRIX)
 
 void gct_data_matrix_new (char const *name, void (*loader) (double **values, int *cols, int *rows))
 {
